@@ -1,4 +1,4 @@
-// -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; tab-width: 8 -*-
+// -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; indent-tabs-mode: nil; -*-
 //
 // Formula.h: Rcpp R/C++ interface class library -- formula
 //
@@ -27,19 +27,19 @@
 
 namespace Rcpp{ 
 
-class Formula : public Language {
-public:
+    class Formula : public Language {
+    public:
 
-	Formula() ;
-	
-	Formula(SEXP lang) throw(not_compatible) ;
+        Formula() ;
+        
+        Formula(SEXP lang);
 
-	Formula(const Formula& other) ;
-	explicit Formula( const std::string& code ) throw(not_compatible) ; 
+        Formula(const Formula& other) ;
+        explicit Formula( const std::string& code ); 
 
-	Formula& operator=(const Formula& other) ;
-	
-} ; 
+        Formula& operator=(const Formula& other) ;
+        
+    } ; 
 
 } // namespace Rcpp
 
